@@ -1,7 +1,8 @@
-from pytest import raises
-import _pytest._code
 import six
 
+import _pytest._code
+from pytest import raises
+
 
 def otherfunc(a, b):
     assert a == b
@@ -247,7 +248,7 @@ class TestCustomAssertMsg(object):
         b = 2
         assert (
             A.a == b
-        ), "A.a appears not to be b\n" "or does not appear to be b\none of those"
+        ), "A.a appears not to be b\nor does not appear to be b\none of those"
 
     def test_custom_repr(self):
         class JSON(object):
