@@ -1,6 +1,6 @@
 """ hook specifications for pytest plugins, invoked from main.py and builtin plugins.  """
-
 from pluggy import HookspecMarker
+
 from .deprecated import PYTEST_NAMESPACE
 
 
@@ -41,10 +41,10 @@ def pytest_namespace():
         Plugins whose users depend on the current namespace functionality should prepare to migrate to a
         namespace they actually own.
 
-        To support the migration its suggested to trigger ``DeprecationWarnings`` for objects they put into the
+        To support the migration it's suggested to trigger ``DeprecationWarnings`` for objects they put into the
         pytest namespace.
 
-        An stopgap measure to avoid the warning is to monkeypatch the ``pytest`` module, but just as the
+        A stopgap measure to avoid the warning is to monkeypatch the ``pytest`` module, but just as the
         ``pytest_namespace`` hook this should be seen as a temporary measure to be removed in future versions after
         an appropriate transition period.
     """
@@ -562,6 +562,9 @@ def pytest_warning_captured(warning_message, when, item):
         * ``"runtest"``: during test execution.
 
     :param pytest.Item|None item:
+        **DEPRECATED**: This parameter is incompatible with ``pytest-xdist``, and will always receive ``None``
+        in a future release.
+
         The item being executed if ``when`` is ``"runtest"``, otherwise ``None``.
     """
 
@@ -600,9 +603,21 @@ def pytest_exception_interact(node, call, report):
     """
 
 
-def pytest_enter_pdb(config):
+def pytest_enter_pdb(config, pdb):
     """ called upon pdb.set_trace(), can be used by plugins to take special
     action just before the python debugger enters in interactive mode.
 
     :param _pytest.config.Config config: pytest config object
+    :param pdb.Pdb pdb: Pdb instance
+    """
+
+
+def pytest_leave_pdb(config, pdb):
+    """ called when leaving pdb (e.g. with continue after pdb.set_trace()).
+
+    Can be used by plugins to take special action just after the python
+    debugger leaves interactive mode.
+
+    :param _pytest.config.Config config: pytest config object
+    :param pdb.Pdb pdb: Pdb instance
     """
