@@ -27,8 +27,9 @@ class TestGeneralUsage(object):
     def test_config_error(self, testdir):
         testdir.copy_example("conftest_usageerror/conftest.py")
         result = testdir.runpytest(testdir.tmpdir)
-        assert result.ret != 0
+        assert result.ret == EXIT_USAGEERROR
         result.stderr.fnmatch_lines(["*ERROR: hello"])
+        result.stdout.fnmatch_lines(["*pytest_unconfigure_called"])
 
     def test_root_conftest_syntax_error(self, testdir):
         testdir.makepyfile(conftest="raise SyntaxError\n")
@@ -662,11 +663,11 @@ class TestInvocationVariants(object):
         assert result.ret == 0
         result.stdout.fnmatch_lines(
             [
-                "*test_hello.py::test_hello*PASSED*",
-                "*test_hello.py::test_other*PASSED*",
-                "*test_world.py::test_world*PASSED*",
-                "*test_world.py::test_other*PASSED*",
-                "*4 passed*",
+                "test_hello.py::test_hello*PASSED*",
+                "test_hello.py::test_other*PASSED*",
+                "ns_pkg/world/test_world.py::test_world*PASSED*",
+                "ns_pkg/world/test_world.py::test_other*PASSED*",
+                "*4 passed in*",
             ]
         )
 
