@@ -1,12 +1,16 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function
-from xml.dom import minidom
-import py
-import sys
-import os
-from _pytest.junitxml import LogXML
-import pytest
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
 
+import os
+import sys
+from xml.dom import minidom
+
+import py
+
+import pytest
+from _pytest.junitxml import LogXML
 from _pytest.reports import BaseReport
 
 
@@ -476,7 +480,7 @@ class TestPython(object):
         tnode.assert_attr(
             file="test_junit_prefixing.py",
             line="3",
-            classname="xyz.test_junit_prefixing." "TestHello",
+            classname="xyz.test_junit_prefixing.TestHello",
             name="test_hello",
         )
 
@@ -1222,3 +1226,19 @@ def test_set_suite_name(testdir, suite_name):
     assert result.ret == 0
     node = dom.find_first_by_tag("testsuite")
     node.assert_attr(name=expected)
+
+
+def test_escaped_skipreason_issue3533(testdir):
+    testdir.makepyfile(
+        """
+        import pytest
+        @pytest.mark.skip(reason='1 <> 2')
+        def test_skip():
+            pass
+    """
+    )
+    _, dom = runandparse(testdir)
+    node = dom.find_first_by_tag("testcase")
+    snode = node.find_first_by_tag("skipped")
+    assert "1 <> 2" in snode.text
+    snode.assert_attr(message="1 <> 2")
