@@ -1,8 +1,13 @@
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 import argparse
-import sys
 import os
+import sys
+
 import py
+
 import pytest
 from _pytest.config import argparsing as parseopt
 
