@@ -1,6 +1,10 @@
 # encoding: utf-8
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 import sys
+
 import pytest
 
 
