@@ -1,14 +1,24 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 import os
-import py.path
-import pytest
 import sys
+import time
+
+import py.path
+
 import _pytest.pytester as pytester
-from _pytest.pytester import HookRecorder
-from _pytest.pytester import CwdSnapshot, SysModulesSnapshot, SysPathsSnapshot
+import pytest
 from _pytest.config import PytestPluginManager
-from _pytest.main import EXIT_OK, EXIT_TESTSFAILED, EXIT_NOTESTSCOLLECTED
+from _pytest.main import EXIT_NOTESTSCOLLECTED
+from _pytest.main import EXIT_OK
+from _pytest.main import EXIT_TESTSFAILED
+from _pytest.pytester import CwdSnapshot
+from _pytest.pytester import HookRecorder
+from _pytest.pytester import SysModulesSnapshot
+from _pytest.pytester import SysPathsSnapshot
 
 
 def test_make_hook_recorder(testdir):
@@ -176,7 +186,7 @@ def test_makepyfile_unicode(testdir):
         unichr(65)
     except NameError:
         unichr = chr
-    testdir.makepyfile(unichr(0xfffd))
+    testdir.makepyfile(unichr(0xFFFD))
 
 
 def test_makepyfile_utf8(testdir):
@@ -401,3 +411,34 @@ def test_testdir_subprocess(testdir):
 def test_unicode_args(testdir):
     result = testdir.runpytest("-k", u"💩")
     assert result.ret == EXIT_NOTESTSCOLLECTED
+
+
+def test_testdir_run_no_timeout(testdir):
+    testfile = testdir.makepyfile("def test_no_timeout(): pass")
+    assert testdir.runpytest_subprocess(testfile).ret == EXIT_OK
+
+
+def test_testdir_run_with_timeout(testdir):
+    testfile = testdir.makepyfile("def test_no_timeout(): pass")
+
+    timeout = 120
+
+    start = time.time()
+    result = testdir.runpytest_subprocess(testfile, timeout=timeout)
+    end = time.time()
+    duration = end - start
+
+    assert result.ret == EXIT_OK
+    assert duration < timeout
+
+
+def test_testdir_run_timeout_expires(testdir):
+    testfile = testdir.makepyfile(
+        """
+        import time
+
+        def test_timeout():
+            time.sleep(10)"""
+    )
+    with pytest.raises(testdir.TimeoutExpired):
+        testdir.runpytest_subprocess(testfile, timeout=1)
