@@ -1,14 +1,21 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
 
-import _pytest._code
 import inspect
 import os
-import py
-import pytest
 import sys
 import types
-from _pytest import runner, main, outcomes, reports
+
+import py
+
+import _pytest._code
+import pytest
+from _pytest import main
+from _pytest import outcomes
+from _pytest import reports
+from _pytest import runner
 
 
 class TestSetupState(object):
@@ -570,7 +577,20 @@ def test_pytest_exit_msg(testdir):
     result.stderr.fnmatch_lines(["Exit: oh noes"])
 
 
-def test_pytest_fail_notrace(testdir):
+def test_pytest_exit_returncode(testdir):
+    testdir.makepyfile(
+        """
+        import pytest
+        def test_foo():
+            pytest.exit("some exit msg", 99)
+    """
+    )
+    result = testdir.runpytest()
+    assert result.ret == 99
+
+
+def test_pytest_fail_notrace_runtest(testdir):
+    """Test pytest.fail(..., pytrace=False) does not show tracebacks during test run."""
     testdir.makepyfile(
         """
         import pytest
@@ -585,6 +605,21 @@ def test_pytest_fail_notrace(testdir):
     assert "def teardown_function" not in result.stdout.str()
 
 
+def test_pytest_fail_notrace_collection(testdir):
+    """Test pytest.fail(..., pytrace=False) does not show tracebacks during collection."""
+    testdir.makepyfile(
+        """
+        import pytest
+        def some_internal_function():
+            pytest.fail("hello", pytrace=False)
+        some_internal_function()
+    """
+    )
+    result = testdir.runpytest()
+    result.stdout.fnmatch_lines(["hello"])
+    assert "def some_internal_function()" not in result.stdout.str()
+
+
 @pytest.mark.parametrize("str_prefix", ["u", ""])
 def test_pytest_fail_notrace_non_ascii(testdir, str_prefix):
     """Fix pytest.fail with pytrace=False with non-ascii characters (#1178).
