@@ -1,7 +1,10 @@
 """
 terminal reporting of the full testing process.
 """
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 import collections
 import os
 import sys
@@ -9,10 +12,14 @@ import textwrap
 
 import pluggy
 import py
+
 import pytest
 from _pytest.main import EXIT_NOTESTSCOLLECTED
-from _pytest.terminal import TerminalReporter, repr_pythonversion, getreportopt
-from _pytest.terminal import build_summary_stats_line, _plugin_nameversions
+from _pytest.terminal import _plugin_nameversions
+from _pytest.terminal import build_summary_stats_line
+from _pytest.terminal import getreportopt
+from _pytest.terminal import repr_pythonversion
+from _pytest.terminal import TerminalReporter
 
 
 DistInfo = collections.namedtuple("DistInfo", ["project_name", "version"])
@@ -154,7 +161,7 @@ class TestTerminal(object):
         )
         result = testdir.runpytest(p2)
         result.stdout.fnmatch_lines(["*test_p2.py .*", "*1 passed*"])
-        result = testdir.runpytest("-v", p2)
+        result = testdir.runpytest("-vv", p2)
         result.stdout.fnmatch_lines(
             ["*test_p2.py::TestMore::test_p1* <- *test_p1.py*PASSED*"]
         )
@@ -170,7 +177,7 @@ class TestTerminal(object):
                 """
             )
         )
-        result = testdir.runpytest("-v")
+        result = testdir.runpytest("-vv")
         assert result.ret == 0
         result.stdout.fnmatch_lines(["*a123/test_hello123.py*PASS*"])
         assert " <- " not in result.stdout.str()
